@@ -79,13 +79,11 @@ end
 
 desc 'Run spec tests and clean the fixtures directory if successful'
 task :spec do |_t, args|
-  begin
-    Rake::Task[:spec_prep].invoke
-    Rake::Task[:spec_standalone].invoke(*args.extras)
-    Rake::Task[:spec_clean].invoke
-  ensure
-    Rake::Task[:spec_clean_symlinks].invoke
-  end
+  Rake::Task[:spec_prep].invoke
+  Rake::Task[:spec_standalone].invoke(*args.extras)
+  Rake::Task[:spec_clean].invoke
+ensure
+  Rake::Task[:spec_clean_symlinks].invoke
 end
 
 desc 'Run spec tests with ruby simplecov code coverage'
@@ -98,13 +96,11 @@ end
 
 desc 'Run spec tests in parallel and clean the fixtures directory if successful'
 task :parallel_spec do |_t, args|
-  begin
-    Rake::Task[:spec_prep].invoke
-    Rake::Task[:parallel_spec_standalone].invoke(*args.extras)
-    Rake::Task[:spec_clean].invoke
-  ensure
-    Rake::Task[:spec_clean_symlinks].invoke
-  end
+  Rake::Task[:spec_prep].invoke
+  Rake::Task[:parallel_spec_standalone].invoke(*args.extras)
+  Rake::Task[:spec_clean].invoke
+ensure
+  Rake::Task[:spec_clean_symlinks].invoke
 end
 
 desc 'Parallel spec tests'
@@ -116,7 +112,7 @@ task :parallel_spec_standalone do |_t, args|
   else
 
     args = ['-t', 'rspec']
-    args.push('--').concat(ENV['CI_SPEC_OPTIONS'].strip.split(' ')).push('--') unless ENV['CI_SPEC_OPTIONS'].nil? || ENV['CI_SPEC_OPTIONS'].strip.empty?
+    args.push('--').concat(ENV['CI_SPEC_OPTIONS'].strip.split).push('--') unless ENV['CI_SPEC_OPTIONS'].nil? || ENV['CI_SPEC_OPTIONS'].strip.empty?
     args.concat(Rake::FileList[pattern].to_a)
 
     ParallelTests::CLI.new.run(args)
@@ -126,39 +122,25 @@ end
 
 desc 'Build puppet module package'
 task :build do
-  if Gem::Specification.find_by_name('puppet').version < Gem::Version.new('6.0.0')
-    Rake::Task['build:pmt'].invoke
-  else
-    Rake::Task['build:pdk'].invoke
-  end
+  Rake::Task['build:pdk'].invoke
 end
 
 namespace :build do
-  desc 'Build Puppet module package with PMT (Puppet < 6.0.0 only)'
-  task :pmt do
-    require 'puppet/face'
-
-    pmod = Puppet::Face['module', :current]
-    pmod.build('./')
-  end
-
   desc 'Build Puppet module with PDK'
   task :pdk do
-    begin
-      require 'pdk/util'
-      require 'pdk/module/build'
+    require 'pdk/util'
+    require 'pdk/module/build'
 
-      path = PDK::Module::Build.invoke(force: true, 'target-dir': File.join(Dir.pwd, 'pkg'))
-      puts "Module built: #{path}"
-    rescue LoadError
-      _ = `pdk --version`
-      unless $CHILD_STATUS.success?
-        warn 'Unable to build module. Please install PDK or add the `pdk` gem to your Gemfile.'
-        abort
-      end
-
-      system('pdk build --force')
+    path = PDK::Module::Build.invoke(force: true, 'target-dir': File.join(Dir.pwd, 'pkg'))
+    puts "Module built: #{path}"
+  rescue LoadError
+    _ = `pdk --version`
+    unless $CHILD_STATUS.success?
+      warn 'Unable to build module. Please install PDK or add the `pdk` gem to your Gemfile.'
+      abort
     end
+
+    system('pdk build --force')
   end
 end
 
@@ -171,6 +153,7 @@ require 'puppet-lint/tasks/puppet-lint'
 # Must clear as it will not override the existing puppet-lint rake task since we require to import for
 # the PuppetLint::RakeTask
 Rake::Task[:lint].clear
+PuppetLint.configuration.fail_on_warnings = true
 # Utilize PuppetLint global configuration so that these settings can be tweaked by
 # spec_helper.rb in an individual module
 PuppetLint.configuration.relative = true
@@ -191,8 +174,9 @@ puppet_lint_disable_checks = %w[
   documentation
   single_quote_string_with_variables
 ]
+
 puppet_lint_disable_checks.each do |check|
-  PuppetLint.configuration.send("disable_#{check}")
+  PuppetLint.configuration.send(:"disable_#{check}")
 end
 PuppetLint::RakeTask.new(:lint)
 
@@ -208,10 +192,6 @@ PuppetSyntax.exclude_paths << 'pkg/**/*'
 PuppetSyntax.exclude_paths << 'vendor/**/*'
 PuppetSyntax.exclude_paths << '.vendor/**/*'
 PuppetSyntax.exclude_paths << 'plans/**/*'
-if Puppet.version.to_f < 4.0
-  PuppetSyntax.exclude_paths << 'types/**/*'
-end
-PuppetSyntax.future_parser = true if ENV['FUTURE_PARSER'] == 'yes'
 
 desc 'Check syntax of Ruby files and call :syntax and :metadata_lint'
 task :validate do
@@ -227,14 +207,13 @@ task :validate do
       warn 'Skipping metadata validation; the metadata-json-lint gem was not found'
     end
   end
-end
 
-task :metadata do
-  warn "The 'metadata' task is deprecated. Please use 'metadata_lint' instead."
-  if Rake::Task.task_defined?(:metadata_lint)
-    Rake::Task[:metadata_lint].invoke
-  else
-    warn 'Skipping metadata validation; the metadata-json-lint gem was not found'
+  if File.exist?('REFERENCE.md')
+    if Rake::Task.task_defined?('strings:validate:reference')
+      Rake::Task['strings:validate:reference'].invoke
+    else
+      warn 'Skipping reference documentation validation; the puppet-strings gem was not found'
+    end
   end
 end
 
@@ -248,7 +227,7 @@ task :compute_dev_version do
     version = modinfo['version']
   elsif File.exist?('Modulefile')
     modfile = File.read('Modulefile')
-    version = modfile.match(%r{\nversion +['"](.*)['"]})[1]
+    version = modfile.match(/\nversion +['"](.*)['"]/)[1]
   else
     raise 'Could not find a metadata.json or Modulefile! Cannot compute dev version without one or the other!'
   end
@@ -260,11 +239,11 @@ task :compute_dev_version do
   # If the branch is a release branch we append an 'r' into the new_version,
   # this is due to the release branch buildID conflicting with main branch when trying to push to the staging forge.
   # More info can be found at https://tickets.puppetlabs.com/browse/FM-6170
-  new_version = if build = (ENV['BUILD_NUMBER'] || ENV['TRAVIS_BUILD_NUMBER'])
+  new_version = if (build = ENV.fetch('BUILD_NUMBER', nil))
                   if branch.eql? 'release'
-                    '%s-%s%04d-%s' % [version, 'r', build, sha] # legacy support code # rubocop:disable Style/FormatStringToken
+                    format('%s-%s%04d-%s', version, 'r', build, sha) # legacy support code
                   else
-                    '%s-%04d-%s' % [version, build, sha] # legacy support code # rubocop:disable Style/FormatStringToken
+                    format('%s-%04d-%s', version, build, sha) # legacy support code
                   end
                 else
                   "#{version}-#{sha}"
@@ -315,7 +294,9 @@ namespace :check do
 
   desc 'Fails if directories contain the files specified in .gitignore'
   task :git_ignore do
-    matched = `git ls-files --ignored --exclude-standard`
+    matched = `git ls-files --ignored --exclude-standard --cached`
+    raise 'git ls-files failed' unless $CHILD_STATUS.success?
+
     unless matched == ''
       puts matched
       raise 'File specified in .gitignore has been committed'
@@ -340,9 +321,7 @@ begin
     # Use Rubocop's Github Actions formatter if possible
     if ENV['GITHUB_ACTIONS'] == 'true'
       rubocop_spec = Gem::Specification.find_by_name('rubocop')
-      if Gem::Version.new(rubocop_spec.version) >= Gem::Version.new('1.2')
-        task.formatters << 'github'
-      end
+      task.formatters << 'github' if Gem::Version.new(rubocop_spec.version) >= Gem::Version.new('1.2')
     end
   end
 rescue LoadError
@@ -384,9 +363,7 @@ def create_gch_task(changelog_user = nil, changelog_project = nil, changelog_sin
     # rubocop:enable Lint/NestedMethodDefinition
 
     GitHubChangelogGenerator::RakeTask.new :changelog do |config|
-      if ENV['CHANGELOG_GITHUB_TOKEN'].nil?
-        raise "Set CHANGELOG_GITHUB_TOKEN environment variable eg 'export CHANGELOG_GITHUB_TOKEN=valid_token_here'"
-      end
+      raise "Set CHANGELOG_GITHUB_TOKEN environment variable eg 'export CHANGELOG_GITHUB_TOKEN=valid_token_here'" if ENV['CHANGELOG_GITHUB_TOKEN'].nil?
 
       config.user = changelog_user || changelog_user_from_metadata
       config.project = changelog_project || changelog_project_from_metadata
@@ -402,16 +379,16 @@ def create_gch_task(changelog_user = nil, changelog_project = nil, changelog_sin
       config.configure_sections = {
         'Changed' => {
           'prefix' => '### Changed',
-          'labels' => ['backwards-incompatible'],
+          'labels' => ['backwards-incompatible']
         },
         'Added' => {
           'prefix' => '### Added',
-          'labels' => %w[feature enhancement],
+          'labels' => %w[feature enhancement]
         },
         'Fixed' => {
           'prefix' => '### Fixed',
-          'labels' => ['bugfix'],
-        },
+          'labels' => ['bugfix']
+        }
       }
     end
   else
