@@ -1,15 +1,18 @@
 # frozen_string_literal: true
 
 if ENV['COVERAGE'] == 'yes'
-  require 'simplecov'
-  require 'simplecov-console'
-  require 'codecov'
+  begin
+    require 'simplecov'
+    require 'simplecov-console'
+  rescue LoadError
+    raise 'Add the simplecov and simplecov-console gems to Gemfile to enable this task'
+  end
 
   SimpleCov.formatters = [
     SimpleCov::Formatter::HTMLFormatter,
-    SimpleCov::Formatter::Console,
-    SimpleCov::Formatter::Codecov,
+    SimpleCov::Formatter::Console
   ]
+
   SimpleCov.start do
     track_files 'lib/**/*.rb'
 
@@ -40,7 +43,7 @@ RSpec.shared_context 'with a rake task', type: :task do
 
   include FakeFS::SpecHelpers
 
-  let(:task_name) { self.class.top_level_description.sub(%r{\Arake }, '') }
+  let(:task_name) { self.class.top_level_description.delete_prefix('rake ') }
 end
 
 # configure RSpec after including all the code
@@ -48,7 +51,6 @@ RSpec.configure do |config|
   config.expect_with :rspec do |c|
     c.syntax = :expect
   end
-  config.mock_with :rspec
 
   config.include_context 'with a rake task', type: :task
 end
